@@ -12,7 +12,7 @@
 #              with the application.
 # ----------------------------------------------------------------------------
 # $Source: src/decimalfp/_pydecimalfp.py $
-# $Revision: 2020-12-11T18:33:27+01:00 $
+# $Revision: 2021-04-14T22:07:35+02:00 $
 
 
 """Decimal fixed-point arithmetic."""
@@ -1477,8 +1477,15 @@ def set_dflt_rounding_mode(rounding: ROUNDING):
     _dflt_rounding_mode = rounding
 
 
+# Some Decimal constants
+ZERO = Decimal(0)
+ONE = Decimal(1)
+
+
 __all__ = [
     'Decimal',
+    'ZERO',
+    'ONE',
     'ROUNDING',
     'get_dflt_rounding_mode',
     'set_dflt_rounding_mode',
